---
title: <span class="badge object-type-array"></span> ObjectMatcher
---
# <span class="badge object-type-array"></span> ObjectMatcher

## Definition

```python
ObjectMatcher: typing.TypeAlias = list[str]
```
